%define oname OpenSP

%define lib_major 5
%define lib_name  %mklibname osp %{lib_major}
%define dev_name  %mklibname osp -d

Summary:    The OpenJade Group's SGML and XML parsing tools
Name:       opensp
Version:    1.5.2
Release:    %mkrel 27
License:    MIT
Group:      Publishing
URL:        https://openjade.sourceforge.net/
Source:     https://download.sourceforge.net/openjade/%{oname}-%{version}.tar.bz2
Patch0:     opensp-multilib.patch
Patch1:     opensp-nodeids.patch
Patch2:     opensp-sigsegv.patch
Patch3:     opensp-manpage.patch
Patch4:     opensp-configure-c99.patch
BuildRequires:  xmlto
BuildRequires:  jadetex
Provides:   OpenSP = %{version}-%{release}
Obsoletes:  OpenSP < 1.5.2-11

%description
This package is a collection of SGML/XML tools called OpenSP. It is a fork from
James Clark's SP suite. These tools are used to parse, validate, and normalize
SGML and XML files.

%package -n %{lib_name}
Summary:    Runtime library for the OpenJade group's SP suite
Group:      System/Libraries
Obsoletes:  %{_lib}OpenSP5 < 1.5.2-11

%description -n %{lib_name}
This is the SP suite's shared library runtime support.  This C++
library contains entity management functions, parsing functions, and
other functions useful for SGML/XML/DSSSL development.

%package -n %{dev_name}
Summary:    Libraries and include files for developing OpenSP applications
Group:      Development/C
Requires:   %{lib_name} = %{version}-%{release}
Provides:   lib%{name}-devel = %{version}-%{release}
Provides:   %{name}-devel = %{version}-%{release}
Provides:   lib%{oname}-devel = %{version}-%{release}
Provides:   %{oname}-devel = %{version}-%{release}
Obsoletes:  %{_lib}OpenSP5-devel < 1.5.2-11

%description -n %{dev_name}
This contains include files and libraries for OpenSP.
This C++ library contains entity management functions, parsing functions,
and other functions useful for SGML/XML/DSSSL development.

%prep
%setup -q -n %{oname}-%{version}
%autopatch -p1

# ensure that applying the above patches doesn't cause lib/parser_inst.cxx to
# be regenerated

touch lib/parser_inst.cxx

%build
%configure \
    --disable-static \
    --enable-http \
    --enable-default-catalog=%{_sysconfdir}/sgml/catalog  \
    --enable-default-search-path=%{_datadir}/sgml:%{_datadir}/xml
%make_build

%install
%make_install

# oMy, othis ois osilly.
for file in nsgmls sgmlnorm spam spent sx ; do
    ln -s o$file %{buildroot}%{_bindir}/$file
    echo ".so man1/o${file}.1" > %{buildroot}%{_mandir}/man1/${file}.1
done

# Rename sx to sgml2xml.
mv %{buildroot}%{_bindir}/sx %{buildroot}%{_bindir}/sgml2xml
mv %{buildroot}%{_mandir}/man1/{sx,sgml2xml}.1

# Clean out (installed) redundant copies of the docs and DTDs.
rm -rf %{buildroot}%{_docdir}/OpenSP
rm -rf %{buildroot}%{_datadir}/OpenSP

%find_lang sp5

%ifarch aarch64
export QA_RPATHS=0x0001
%endif

%check
make check || : # TODO: failures as of 1.5.2 :(

%files -f sp5.lang
%doc doc/*.htm AUTHORS ChangeLog NEWS README
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*.1*

%files -n %{lib_name}
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/libosp.so.%{lib_major}{,.*}

%files -n %{dev_name}
%{_libdir}/libosp.so
%{_includedir}/OpenSP/


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.5.2-27.mga10
+ Revision: 2221958
- Mageia 10 Mass Rebuild

* Sat Apr 06 2024 wally <wally> 1.5.2-26.mga10
+ Revision: 2055076
- add Fedora patch to port configure script to C99 to fix build

* Tue Feb 14 2023 daviddavid <daviddavid> 1.5.2-25.mga9
+ Revision: 1942139
- fix license to MIT

* Wed Nov 02 2022 ghibo <ghibo> 1.5.2-24.mga9
+ Revision: 1901665
- Skip rpath checking for aarch64
- Skip rpath checking for aarch64
- Rebuild for aging
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Aug 10 2020 bcornec <bcornec> 1.5.2-21.mga8
+ Revision: 1613140
- Remove pseudo aarch build feature which breaks x86 build at least

* Fri Feb 14 2020 umeabot <umeabot> 1.5.2-20.mga8
+ Revision: 1515728
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 1.5.2-19.mga7
+ Revision: 1300036
- Mageia 7 Mass Rebuild

* Sun Jun 03 2018 wally <wally> 1.5.2-18.mga7
+ Revision: 1233892
- fix build on aarch64

* Thu Sep 07 2017 guillomovitch <guillomovitch> 1.5.2-17.mga7
+ Revision: 1151818
- sync with fedora package

* Fri Feb 12 2016 umeabot <umeabot> 1.5.2-16.mga6
+ Revision: 956551
- Mageia 6 Mass Rebuild

* Thu Oct 15 2015 blino <blino> 1.5.2-15.mga6
+ Revision: 891897
- remove empty langs filelist to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 1.5.2-14.mga5
+ Revision: 743910
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.2-13.mga5
+ Revision: 683244
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.5.2-12.mga4
+ Revision: 532505
- Mageia 4 Mass Rebuild

* Tue Aug 20 2013 wally <wally> 1.5.2-11.mga4
+ Revision: 468546
- rename pkg as opensp
- fix lib and devel pkg names
- clean .spec a bit

* Fri Jan 11 2013 umeabot <umeabot> 1.5.2-10.mga3
+ Revision: 345075
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jul 18 2012 rtp <rtp> 1.5.2-9.mga3
+ Revision: 272294
- add missing BR on docbook-style-xsl

* Sun Jan 09 2011 blino <blino> 1.5.2-8.mga1
+ Revision: 1584
- remove old ldconfig scriptlets
- imported package OpenSP


* Sun Jan 03 2010 Funda Wang <fwang@mandriva.org> 1.5.2-7mdv2010.1
+ Revision: 485962
- BR dtd412

  + Christophe Fergeau <cfergeau@mandriva.com>
    - rebuild

  + Antoine Ginies <aginies@mandriva.com>
    - rebuild

* Tue Jun 17 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.5.2-5mdv2009.0
+ Revision: 223373
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Mar 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1.5.2-4mdv2008.1
+ Revision: 178765
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Jun 21 2007 Christiaan Welvaart <spturtle@mandriva.org> 1.5.2-3mdv2008.0
+ Revision: 42318
- add version to devel provides

* Fri Jun 08 2007 Götz Waschk <waschk@mandriva.org> 1.5.2-2mdv2008.0
+ Revision: 37270
- fix major
- new version
- update patches (Frederic Himpe)

* Thu Apr 19 2007 Andreas Hasenack <andreas@mandriva.com> 1.5-12mdv2008.0
+ Revision: 14997
- Import OpenSP



* Sat Sep 02 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.5-1mdv2007.0
- Rebuild

* Sun May 28 2006 Stefan van der Eijk <stefan@eijk.nu> 1.5-11mdk
- %%mkrel

* Fri Apr 14 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.5-10mdk
- patch3: try to find an external DTD's public ID in the local 
          catalogs before dereferencing the system ID

* Thu Nov 03 2005 Götz Waschk <waschk@mandriva.org> 1.5-9mdk
- Rebuild

* Thu Jun 10 2004 Götz Waschk <waschk@linux-mandrake.com> 1.5-8mdk
- rebuild for broken libstdc++6-devel-3.4.1-0.2mdk

* Thu Jun  3 2004 Montel Laurent <lmontel@n2.mandrakesoft.com> 1.5-7mdk
- Rebuild 

* Mon Nov 24 2003 Stefan van der Eijk <stefan@eijk.nu> 1.5-6mdk
- rebuild 4 reupload (alpha)

* Mon Jul 21 2003 Frederic Crozat <fcrozat@mandrakesoft.com> - 1.5-5mdk
- Rebuild

* Wed Jun 11 2003 Warly <warly@mandrakesoft.com> 1.5-4mdk
- Fix Per Øyvind Karlse patch 0 to be able to build openjade 1.3.2

* Fri Jun 06 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 1.5-3mdk
- compile with same options as openjade
- Patch1 from RH

* Fri Jun 06 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 1.5-2mdk
- gcc-3.3 fix from RH (Patch0)

* Mon Feb  3 2003 Frederic Crozat <fcrozat@mandrakesoft.com> 1.5-1mdk
- Initial Mandrake package
